### Name: apply
### Title: S3 generic apply method for msSet Class
### Aliases: apply apply.msSet apply.default
### Keywords: classes

### ** Examples

if (!exists("qcset")) data("qcset", package="msProcess")

# find the means of each spectrum
# and convert the result to a single-row matrix
means <- apply(qcset, MARGIN=2, mean)
nc <- NCOL(qcset$intensity)
means <- matrix(means, ncol=nc)
print(means)

# add the means (single-row) matrix to the original
# msSet object and verify its existence
z <- msSet(qcset, means=means)
names(z)
is.matrix(z$means)

# to illustrate the use of the 'covar' argument in apply,
# create a faux function that finds tha maximum absolute
# difference between each spectrum and its mean value
foo <- function(x,meanvals) max(abs(x-meanvals))
maxdiff <- as.vector(apply(z, MARGIN=2, FUN=foo, covar=list(meanvals=means)))
print(maxdiff)

# verify the results: should get vector of nc zeros
unlist(lapply(seq(along=maxdiff), function(i,z,maxdiff)
  vecnorm(max(abs(z$intensity[,i]-z$means[,i])) - maxdiff[i]),
  z=z, maxdiff=maxdiff))



