### Name: eventHistory
### Title: Event History Creation
### Aliases: eventHistory [.eventHistory print.eventHistory
### Keywords: utilities

### ** Examples

## create a list of simple objects 
z <- list(dog="chihuahua", vals=1:5, colors=c("red","green","blue"))

## remove mean from vals and document as a history 
## event 
z$vals <- z$vals - mean(z$vals)
z <- eventHistory(z, "Process A"=list(values="mean removed"))

## now sort the colors and change the dog name, 
## and document both actions in the same call 
## to msHistory as separate processes 
z$colors <- sort(z$colors)
z$dog    <- "pomeranian"
z <- eventHistory(z, "Process B"=list(colors="sorted alphabetically"),
    "Process C"=list(dog="name change", result="more hair"))

## add an event without proceedings 
z <- eventHistory(z, "Event A", "Event B")

## print the history 
print(getHistory(z))

## replace some of the events with new information 
z <- eventHistory(z, "Event A"=list(show="pony"), "Process A",
action="merge")
print(getHistory(z))

## prepend some new events 
z <- eventHistory(z, new=list(alpha="first greek letter"),
    action="prepend")
print(getHistory(z))

## replace event history altogether 
z <- eventHistory(z, newest=list(omega="final greek letter"),
    action="replace")
print(getHistory(z))

## return an object of class eventHistory, i.e., 
## not attached to any other object 
eventHistory(NULL,
    symphony=list(string="violins and cellos", percussion="drums",
       reed="flutes and oboes"))



