### Name: msAlign
### Title: Peak Alignment
### Aliases: msAlign msAlignCluster msAlignGap msAlignMRD msAlignVote
### Keywords: manip

### ** Examples

if (!exists("qcset")) data("qcset", package="msProcess")

## extract several spectra from the build-in
## dataset
z <- qcset[, 1:8]

## denoising
z <- msDenoise(z, FUN="wavelet", n.level=10, thresh.scale=2)

## local noise estimation
z <- msNoise(z, FUN="mean")

## baseline subtraction
z <- msDetrend(z, FUN="monotone", attach=TRUE)

## intensity normalization
z <- msNormalize(z)

## peak detection
z <- msPeak(z, FUN="simple", use.mean=FALSE, snr=2)

## peak alignment
z <- msAlign(z, FUN="cluster", snr.thresh=10,
    mz.precision=0.004)

## extract the peak.class
z[["peak.class"]]

## visualize the alignment
plot(z, process="msAlign", subset=1:8, offset=100,
    xlim=c(13000, 17000), lty=c(1,4))



