### Name: msCalibrate
### Title: Constructor Function for Objects of Class msCalibrate
### Aliases: msCalibrate coef.msCalibrate formula.msCalibrate
###   plot.msCalibrate predict.msCalibrate print.msCalibrate
### Keywords: manip

### ** Examples

## set up parameters 
u  <- 20000
t0 <- 0.0038
a  <- 0.0002721697
b  <- 0.0

## simulate m/z and time-of-flight 
tof <- seq(from=20, to=60, length=7)
mz  <- u*(a*(tof - t0)^2 + b)

## perform quadratic fitting 
fit <- msCalibrate(mz=mz, tof=tof, u=u, FUN="lm")

## check the fitted parameters 
print(fit)

## do prediction: convert tof to mass 
tof2 <- seq(from=min(tof), to=max(tof), length=60)
mz.predicted <- predict(fit, tof2)

## visualization 
plot(fit, type="p", col=1, xlim=range(tof2),
    ylim=range(mz.predicted))
lines(tof2, mz.predicted, col=2)
legend(x=20, y=20000, col=1:2, pch="o ", lty=c(0,1),
    legend=c("true", "predicted"))



