### Name: msDenoise
### Title: Mother Function for Mass Spectra Denoising
### Aliases: msDenoise
### Keywords: manip

### ** Examples

if (!exists("qcset")) data("qcset", package="msProcess")

## denoise a spectrum portion via waveshrink and a
## smoothing function
mz   <- (qcset$mz > 3000 & qcset$mz < 5000)
data <- qcset[mz, 1, drop=FALSE]

## add a little Gaussian noise for illustration
noise  <- rnorm(length(data$intensity), sd=stdev(data$intensity)/3)
xnoise <- data
xnoise$intensity <- data$intensity +
    matrix(noise, ncol=1)

## denoise using the supported routines
z1 <- msDenoise(xnoise, FUN="wavelet")
z2 <- msDenoise(xnoise, FUN="smooth")
z3 <- msDenoise(xnoise, FUN="mrd", levels=4:6)

## create a user-defined (albeit naive) denoising
## function
my.fun <- function(x, wavelet="d4"){
    filt <- wavDaubechies(wavelet=wavelet, norm=FALSE)$scaling
    return(filter(x, filt))
}
z4 <- msDenoise(xnoise, FUN=my.fun, wavelet="s12")

## create a stackplot of the results
z <- list(original=data$intensity[,1],
    noisy=xnoise$intensity[,1],
    waveshrink=z1$intensity[,1],
    smooth=z2$intensity[,1],
    mrd=z3$intensity[,1],
    "my function"=z4$intensity[,1])
wavStackPlot(z, col=seq(along=z), same.scale=TRUE)



