### Name: msDenoiseMRD
### Title: Denoising a Mass Spectrum via Partial Summation of an MRD
### Aliases: msDenoiseMRD
### Keywords: manip

### ** Examples

if (!exists("qcset")) data("qcset", package="msProcess")

## obtain a subset of a mass spectrum and add some
## noise
x <- qcset$intensity[5000:7000,1]
sd.noise <- 2
set.seed(100)
xnoise <- x + rnorm(length(x), sd=sd.noise)
mz <- as.matrix(as.numeric(names(x)))

## define two different ranges of summation levels
lev1 <- 6:8
lev2 <- 4:8

## calculate MODWT MRDs over these levels
z1 <- msDenoiseMRD(xnoise, levels=lev1)
z2 <- msDenoiseMRD(xnoise, levels=lev2)

## plot the results
Slab <- "S8"
lab1 <- paste(paste("D", lev1, sep="", collapse="+"), Slab, sep="+")
lab2 <- paste(paste("D", lev2, sep="", collapse="+"), Slab, sep="+")

msPlot(matlines=list(
    list(x=mz, y=cbind(z1, z2), lty=1, lwd=3),
    list(x=mz, y=cbind(xnoise, xnoise), type="p", pch="o", cex=0.15)),
    yref=FALSE, xlab="m/z", ylab="MODWT MRD",
    text=list(x=rep(8300,2), y=c(2300,1650),
    labels=c(lab2,lab1), adj=0, col=2:1))



