### Name: msDenoiseWavelet
### Title: Denoising a Mass Spectrum via Wavelet Shrinkage
### Aliases: msDenoiseWavelet
### Keywords: manip

### ** Examples

if (!exists("qcset")) data("qcset", package="msProcess")

## create plot layout
old.par <- par()
par(mfrow=c(3,2))

## grab portion of a mass spectrum and plot
x <- qcset$intensity[5000:7000,1]
plot(x,type="l");title("original")

## create noise and add it to the spectrum portion
sd.noise <- 2
xnoise <- x + rnorm(length(x), sd=sd.noise)
plot(xnoise,type="l")
title(paste("original + noise (sd=", round(sd.noise,3),")",sep=""))

## plot MODWT waveshrink results after scaling the
## estimated threshold values
for ( k in seq(0.5,2,length=4)){

    y <- msDenoiseWavelet(xnoise, wavelet="s8",
       shrink.fun="hard", thresh.fun="universal",
       thresh.scale=k, xform="modwt")
    plot(y,type="l")
    title(paste("WS: thresh.scale =", round(k,2)))
}

## DWT waveshrink using different threshold
## functions
plot(x,type="l")
title("original")
plot(xnoise,type="l")
title(paste("original + noise (sd=", round(sd.noise,3),")",sep=""))

thresh.funs <- c("universal", "minimax", "adaptive")
for (k in thresh.funs){
    plot(msDenoiseWavelet(xnoise, thresh.fun=k, xform="dwt"), type="l", ylab="y")
    title(paste("WS: thresh.fun =", k))
}

## restore original plot layout
par(old.par)



