### Name: msNoise
### Title: Local Noise Estimation
### Aliases: msNoise
### Keywords: manip

### ** Examples

if (!exists("qcset")) data("qcset", package="msProcess")

## denoise a noise contaminated spectrum portion
## via waveshrink
mz     <- (qcset$mz > 3000 & qcset$mz < 5000)
data   <- qcset[mz, 1, drop=FALSE]
noise  <- rnorm(length(data$intensity), sd=stdev(data$intensity)/3)
xnoise <- data

xnoise$intensity <- data$intensity + matrix(noise, ncol=1)
z <- vector("list", length=4)
z[[1]] <- msDenoise(xnoise, FUN="wavelet")

## smooth the resulting noise estimates to form a
## localized estimate of the noise using
## various supported methods

z[[2]] <- msNoise(z[[1]], FUN="spline")
z[[3]] <- msNoise(z[[1]], FUN="loess")

## create a user-defined smoothing function
my.fun <- function(x, wavelet="d4"){
    filt <- wavDaubechies(wavelet=wavelet, norm=FALSE)$scaling
    return(filter(x, filt))
}
z[[4]] <- msNoise(z[[1]], FUN=my.fun, wavelet="s12")

## create a stackplot of the results
type <- c("noise", rep("noise.local", 3))
for (i in 1:4){
    z[[i]] <- as.vector(z[[i]][[type[i]]])
}
names(z) <- c("noise","spline", "loess", "my function")
wavStackPlot(z, col=seq(along=z), same.scale=TRUE)



