### Name: msNormalize
### Title: Mother Function for Intensity Normalization
### Aliases: msNormalize
### Keywords: manip

### ** Examples

if (!exists("qcset")) data("qcset", package="msProcess")

## normalize a subset of spectra in the
## qcset object using total ion current.
data <- qcset[,1:8]
zion <- msNormalize(data, FUN="tic")
plot(zion, process="msNormalize", subset=1:8,
xlim=c(13000, 17000), lty=c(1,4), lwd=1:2)

## normalize a subset of spectra in the
## qcset object using a standard normal
## variate transformation.
zsnv <- msNormalize(data, FUN="snv")
plot(zsnv, process="msNormalize", subset=1:8,
xlim=c(13000, 17000), lty=c(1,4), lwd=1:2)

## perform a multiresolution decomposition of each
## spectrum in the intensity matrix, sum over
## levels 6-8, then normalize using the SNV
## transformation (this process is equivalent
## to scale-based normalization (SBN)).
data <- msDenoise(data, FUN="mrd", levels=6:8, keep.smooth=FALSE)
zsnv <- msNormalize(data, FUN="snv")
plot(zsnv, process="msNormalize", subset=1:8,
xlim=c(13000, 17000), lty=c(1,4), lwd=1:2)



