### Name: msPeak
### Title: Mother Function for Peak Detection
### Aliases: msPeak
### Keywords: manip

### ** Examples

if (!exists("qcset")) data("qcset", package="msProcess")

## extract several spectra from the build-in 
## dataset 
z <- qcset[, 1:8]

## denoising 
z <- msDenoise(z, FUN="wavelet", n.level=10, thresh.scale=2)

## local noise estimation 
z <- msNoise(z, FUN="mean")

## baseline subtraction 
z <- msDetrend(z, FUN="monotone", attach=TRUE)

## intensity normalization based on total ion 
## current 
z <- msNormalize(z, FUN="tic")

## peak detection 
z <- msPeak(z, FUN="simple", use.mean=FALSE, snr=2)

## visualize the detected peaks 
plot(z, process="msPeak", subset=1:8, offset=100,
    xlim=c(13000, 17000))

## perform a similar analysis using a 
## multiresolution decomposition approach 
z <- qcset[, 1:8]
z <- msDenoise(z, FUN="mrd", levels=6, keep.smooth=FALSE)
z <- msPeak(z, FUN="mrd")
plot(z, process="msPeak", subset=1:8, offset=100,
    xlim=c(13000, 17000))

## perform a similar analysis using a CWT approach 
# z <- qcset[, 1:8]
# z <- msPeak(z, FUN="cwt", scale.min=8)
# plot(z, process="msPeak", subset=1:8, offset=100,
#           xlim=c(13000, 17000))



