### Name: msPeakCWT
### Title: Peak Detection via the Continuous Wavelet Transform
### Aliases: msPeakCWT
### Keywords: manip

### ** Examples

if (!exists("qcset")) data("qcset", package="msProcess")

## extract a subset of a single spectrum 
mz  <- qcset$mz
imz <- mz > 3000 & mz < 5000
z   <- as.vector(qcset[imz, 1]$intensity)
mz  <- mz[imz]
plot(mz, z, cex=0.5, ylab="Intensity", xlab="m/z", type="l")

## estimate the peak locations using various 
## minimum CWT scales and overlay the plot 
## locations 
scale.min <- c(2,4,8)
col <- c("green","blue","red")

for (i in seq(along=scale.min)){
    p <- msPeakCWT(mz, z, scale.min=scale.min[i])
    ipeak <- p[["tick.loc"]]
    points(mz[ipeak], z[ipeak], cex=i, col=col[i], pch=1)
}

## add a legend 
if (is.R()){
  legend(3000,10000,pch=1,col=col,legend=paste("scale.min =", scale.min))
} else {
  legend(3000,10000,marks=1,col=col,legend=paste("scale.min =", scale.min))
}

## plot the Holder exponents corresponding to each 
## peak 
hx <- p[["mass.loc"]]
hy <- abs(p[["holder"]])
plot(hx, hy, type="h", xlim=range(mz), lty="dashed", col="blue", xlab="m/z", ylab="|Holder exponent|")
points(hx, hy, col="red", cex=1.2)
lines(mz, rescale(z,c(0,0.5)), lwd=3)
abline(h=0, lty="dotted")
legend(3000,1,col=c("blue","black"), lwd=c(1,3), lty=c("dashed","solid"),
    legend=c("|Holder exponent|", "Scaled spectrum"))



