### Name: msPeakMRD
### Title: Peak Detection via Multiresolution Decomposition
### Aliases: msPeakMRD
### Keywords: manip

### ** Examples

if (!exists("qcset")) data("qcset", package="msProcess")

## extract a subset of a single spectrum
mz  <- qcset$mz
imz <- mz > 3000 & mz < 5000
z   <- as.vector(qcset[imz, 1]$intensity)
mz  <- mz[imz]

## specify the decomposition levels of interest
level <- 6

## calculate the MRD detail
D <- wavMRDSum(z, wavelet="haar",
    levels=level, xform="modwt",
    keep.smooth=FALSE, keep.details=TRUE,
    reflect=TRUE)

## locate MODWT MRD detail features via
## wavelet-based first and second derivative
## approximations
ipeak1 <- msPeakMRD(mz, D, n.level=level)[["tick.loc"]]

## plot the results
plot(D, cex=0.5, ylab=paste("D",level,sep=""), type="b")
abline(v=ipeak1, col="blue", lty="dashed")



