### Name: msQualify
### Title: Quality Assessment of Mass Spectra Data
### Aliases: msQualify predict.msQualify
### Keywords: manip

### ** Examples

## create multiple reference samples with multiple 
## peaks 
set.seed(10)
nrs <- 240
nv <- 35
my.mean <- 10
my.sd <- rnorm(nv)
my.sd <- my.sd - min(my.sd) + 1
rsam <- splus2R::rmvnorm(n=nrs, d=nv, mean=rep(my.mean, nv),
    cov=diag(nv), sd=my.sd)

## run msQualify 
pca <- msQualify(rsam, FUN="princompRob", estim="auto")

## create multiple reference samples with multiple 
## peaks from the same distribution 
nts <- 72
tsam <- splus2R::rmvnorm(n=nts, d=nv, mean=rep(my.mean, nv),
    cov=diag(nv), sd=my.sd)

## predict the quality of the test samples 

quality <- predict(pca, tsam)
quality$pass
if (!is.R()) assign("quality", quality, frame=1)
## check if the distances truly follow 
## chisq(nkeep) distribution 
qqmath(~quality$dist,
    distribution=function(p, df=quality$df) qchisq(p, df),
    panel = function(x, y) {
    panel.grid()
    panel.abline(0, 1)
    panel.qqmath(x, y)
    },
    aspect=1,
    xlab=paste("Chisq(", quality$df, ") Quantile"),
    ylab="mahalanobis distance")



