### Name: msQuantify
### Title: Mother Function for Peak Quantification
### Aliases: msQuantify
### Keywords: manip

### ** Examples

if (!exists("qcset")) data("qcset", package="msProcess")

## extract several spectra from the build-in
## dataset
z <- qcset[, 1:8]

## denoising
z <- msDenoise(z, FUN="wavelet", n.level=10, thresh.scale=2)

## local noise estimation
z <- msNoise(z, FUN="mean")

## baseline subtraction
z <- msDetrend(z, FUN="monotone", attach=TRUE)

## intensity normalization
z <- msNormalize(z)

## peak detection
z <- msPeak(z, FUN="simple", use.mean=FALSE, snr=2)

## peak alignment
z <- msAlign(z, FUN="cluster", snr.thresh=10, mz.precision=0.004)

## peak quantification using intensity
z <- msQuantify(z, measure="intensity")

## extract peak.matrix
z[["peak.matrix"]]

## visualize the peak.matrix
image(z, what="peak.matrix")



